import ruamel.yaml


def format_yaml(file_path):
    yaml = ruamel.yaml.YAML()
    with open(file_path) as f:
        data = yaml.load(f)
    with open(file_path, "w") as f:
        yaml.dump(data, f)



import subprocess
import click


def lint_yaml(file_path):
    result = None
    try:
        result = subprocess.run(["yamllint", file_path], capture_output=True, text=True)
        if result.returncode == 0:
            click.echo(f"{file_path} is valid YAML")
        else:
            print(result.stdout)
    except Exception as e:
        click.echo(f"Error linting {file_path}: {e}")

    return result



import subprocess
import click


def lint_python(file_path):
    result = None
    try:
        result = subprocess.run(["flake8", file_path], check=True)
        if result.returncode == 0:
            click.echo(f"{file_path} is PEP8 compliant")
            print(f"{file_path} is PEP8 compliant")
    except Exception as e:
        click.echo(f"Python linting failed for: {file_path} with error: {e}")

    return result



from linter_cli.linters.python_linter import lint_python
from linter_cli.formatters.python_formatter import format_python


def test_lint_python_file_valid(valid_python_file):
    result = lint_python(valid_python_file)
    assert result.returncode == 0


def test_lint_python_file_invalid(invalid_python_file):
    result = lint_python(invalid_python_file)
    assert result is None


def test_format_python_file(invalid_python_file):
    result = format_python(invalid_python_file)
    assert result.returncode == 0



import pytest
from click.testing import CliRunner


@pytest.fixture
def runner():
    return CliRunner()


@pytest.fixture
def valid_yaml_file(tmp_path):
    content = "valid: yaml\n"
    file_path = tmp_path / "valid.yaml"
    file_path.write_text(content)
    return file_path


@pytest.fixture
def invalid_yaml_file(tmp_path):
    content = """invalid: yaml\n- with\nunexpected: elements"""
    file_path = tmp_path / "invalid.yaml"
    file_path.write_text(content)
    return file_path


@pytest.fixture
def valid_python_file(tmp_path):
    content = "def valid_python():\n    pass\n"
    file_path = tmp_path / "valid.py"
    file_path.write_text(content)
    return file_path


@pytest.fixture
def invalid_python_file(tmp_path):
    content = "def invalid_python():\n    print('invalid python')"
    file_path = tmp_path / "invalid.py"
    file_path.write_text(content)
    return file_path



from linter_cli.linters.yaml_linter import lint_yaml


def test_lint_yaml_file_valid(valid_yaml_file):
    result = lint_yaml(valid_yaml_file)
    assert result.returncode == 0


def test_lint_yaml_file_invalid(invalid_yaml_file):
    result = lint_yaml(invalid_yaml_file)
    assert result.returncode != 0



import subprocess


def format_python(file_path):
    result = None
    try:
        result = subprocess.run(["black", file_path], check=True)
        if result.returncode == 0:
            print(f"{file_path} is formatted")
    except Exception as e:
        print(f"Error formatting {file_path}: {e}")

    return result



"""
Note: We shall not test YAML formatter, as it is highly inconsistent and may not work as expected.
"""

from linter_cli.cli import main


def test_lint_yaml_file_valid(runner, valid_yaml_file):
    result = runner.invoke(main, ["lint", str(valid_yaml_file)])
    assert result.exit_code == 0
    assert "is valid YAML" in result.output
    assert "YAML linting passed for:" in result.output


def test_lint_yaml_file_invalid(runner, invalid_yaml_file):
    result = runner.invoke(main, ["lint", str(invalid_yaml_file)])
    assert result.exit_code == 0
    assert "is valid YAML" not in result.output
    assert "YAML linting passed for:" in result.output


def test_lint_python_file_valid(runner, valid_python_file):
    result = runner.invoke(main, ["lint", str(valid_python_file)])
    assert result.exit_code == 0
    assert "Python linting passed for:" in result.output


def test_lint_python_file_invalid(runner, invalid_python_file):
    result = runner.invoke(main, ["lint", str(invalid_python_file)])
    assert result.exit_code == 0
    assert "Python linting failed for:" in result.output
    assert "error" in result.output


def test_lint_python_file_invalid_with_autofix(runner, invalid_python_file):
    result = runner.invoke(main, ["lint", str(invalid_python_file), "--autofix"])
    assert result.exit_code == 0
    assert "Python linting failed for:" in result.output
    assert "error" in result.output
    assert "Python auto-fixed and saved:" in result.output



from setuptools import setup, find_packages


def read_requirements(file):
    """
    Read a requirements file and return its contents.
    Useful when the user is passing a requirements file to install dependencies.
    :param file: str(path)
    :return: list
    """
    with open(file) as f:
        return f.read().splitlines()


setup(
    name="lintmate",
    version="0.1.0",
    packages=find_packages(),
    install_requires=read_requirements("requirements/base.txt"),
    extras_require={
        "yaml": read_requirements("requirements/yaml.txt"),
        "python": read_requirements("requirements/python.txt"),
    },
    entry_points={
        "console_scripts": [
            "lintmate= linter_cli.cli:main",
        ],
    },
    author="thesujai",
    author_email="sujayscience1234@gmail.com",
    description="A CLI tool for linting and formatting files. Without worying about any dependencies.",
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    url="https://github.com/thesujai/linter-cli",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.9'
)



import os

import click
from importlib import import_module


@click.group()
def main():
    """CLI tool for linting and formatting files."""
    pass


def get_linter(linter_name):
    try:
        linter = import_module(f"linter_cli.linters.{linter_name}")
        return linter
    except ImportError:
        click.echo(
            f"""Linter '{linter_name}' not found.
                        Please install it using `pip install linter-cli[{linter_name}]`"""
        )
        raise


def get_formatter(formatter_name):
    try:
        formatter = import_module(f"linter_cli.formatters.{formatter_name}")
        return formatter
    except ImportError:
        click.echo(
            f"""Formatter '{formatter_name}' not found.
                    Please install it using `pip install linter-cli[{formatter_name}]`"""
        )
        raise


def lint_file(file, autofix):
    if file.endswith((".yaml", ".yml")):
        try:
            linter_module = get_linter("yaml_linter")
            if autofix:
                formatter_module = get_formatter("yaml_formatter")
        except ImportError:
            return
        try:
            linter_module.lint_yaml(file)
            click.echo(f"YAML linting passed for: {file}")
            if autofix:
                formatter_module.format_yaml(file)
                click.echo(f"YAML auto-fixed and saved: {file}")
        except Exception as e:
            click.echo(f"Error processing {file}: {e}")
    elif file.endswith(".py"):
        try:
            linter_module = get_linter("python_linter")
            if autofix:
                formatter_module = get_formatter("python_formatter")
        except ImportError:
            return
        try:
            linter_module.lint_python(file)
            click.echo(f"Python linting passed for: {file}")
            if autofix:
                formatter_module.format_python(file)
                click.echo(f"Python auto-fixed and saved: {file}")
        except Exception as e:
            click.echo(f"Error processing {file}: {e}")


@main.command()
@click.argument("paths", nargs=-1)
@click.option("--autofix", is_flag=True, help="Automatically fix the issues.")
def lint(paths, autofix):
    """Lint and optionally fix files."""
    for path in paths:
        if os.path.isfile(path):
            lint_file(path, autofix)
        elif os.path.isdir(path):
            for root, _, files in os.walk(path):
                for file in files:
                    lint_file(os.path.join(root, file), autofix)
